# -*- coding: utf-8 -*-
import time
import datetime
from Adafruit_LED_Backpack import SevenSegment
from vlcclient import VLCClient
import RPi.GPIO as GPIO     #Für die Ansteuerung der GPIO-Pins
import os

# Interruptroutine für den Drehgeber
def GPIO_Interrupt(channel):
    global volume
    global display
    global vlc
    global noTimeUpdate
    CH_B = GPIO.input(31)
    if (CH_B == 0):
        volume -= 5
    else:
        volume += 5
    if volume > 250:
        volume = 250
    if volume < 0:
        volume = 0
    noTimeUpdate = 20
    display.clear()
    display.print_float(volume, decimal_digits=0)
    display.write_display()
    vlc.volume(volume)

# Erzeuge eine Instanz display für die Standard I2C Adresse (0x70)
display = SevenSegment.SevenSegment()

# Alternativ kann auch eine spezielle I2C adresse verwendet werden. Diese muss an der 7-Segment-Anzeige geändert werden.
# display = SevenSegment.SevenSegment(address=0x74, busnum=1)

# Display initialisieren. Muss aufgerufen werden bevor man das Display benutzen kann.
display.begin()
display.set_brightness(6)

#_PI_ auf die 7-Segment-Anzeige schreiben
#   __A__
#  |     |
#  F     B
#  |__G__|
#  |     |
#  E     C
#  |__D__| .DP
#   
#Bit:   7  6  5  4  3  2  1  0
#Seg:   DP G  F  E  D  C  B  A
#Bsp:   0  1  1  1  0  0  1  1 = 0x73 = "P"
#
display.clear()
display.set_digit_raw(0, bitmask=0x08) #_
display.set_digit_raw(1, bitmask=0x73) #P
display.set_digit_raw(2, bitmask=0x30) #I
display.set_digit_raw(3, bitmask=0x08) #_
display.write_display()

#VLC-Player starten
os.system("vlc &") #Muss als Hintergrundprozess gestartet werden, da sonst das Progamm nicht weiterläuft
time.sleep(8) #Warten, bis VLC gestartet wurde und Befehle empfangen kann

vlc = VLCClient("::1")
vlc.connect()

# GPIO-Pins initialisieren
GPIO.setmode(GPIO.BOARD)
GPIO.setwarnings(False)

#Ausgänge
#GPIO.setup(7, GPIO.OUT)
#GPIO.output(7, GPIO.LOW)

#Eingänge Taster
S1 = 16
GPIO.setup(S1, GPIO.IN) #Taster S1 (GPIO 23) ON/OFF
S2 = 18
GPIO.setup(S2, GPIO.IN) #Taster S2 (GPIO 24)
S3 = 22
GPIO.setup(S3, GPIO.IN) #Taster S3 (GPIO 25)
S4 = 13
GPIO.setup(S4, GPIO.IN) #Taster S4 (GPIO 27)
S5 = 11
GPIO.setup(S5, GPIO.IN) #Taster S5 (GPIO 17)

#Eingänge Drehgeber
ENC_A = 29
GPIO.setup(ENC_A, GPIO.IN) #A (GPIO 5)
ENC_B = 31
GPIO.setup(ENC_B, GPIO.IN) #B (GPIO 6)
ENC_ENTER = 32
GPIO.setup(ENC_ENTER, GPIO.IN) #Enter (GPIO 12)

noTimeUpdate = 0

volume = 60
display.print_float(volume, decimal_digits=0)
display.write_display()

GPIO.add_event_detect(29, GPIO.FALLING, callback = GPIO_Interrupt, bouncetime = 20)

taster1 = 0
taster2 = 0
taster3 = 0
taster4 = 0
taster5 = 0
lastSecond = 0
selPos = 0
selChannel = 0

vlc.clear()         #Playlist löschen
vlc.volume(volume)  #Lautstärke auf Anfangswert stellen
print("Radio start")
vlc.add("/home/pi/Music/startsound.mp3")   #Startjingle

while(True):
    if GPIO.input(S1) == GPIO.LOW:
        #ON/OFF Taster
        #print("Taster 1")
        vlc.clear()
        display.clear()
        display.set_digit_raw(0, bitmask=0x00) #
        display.set_digit_raw(1, bitmask=0x3F) #O
        display.set_digit_raw(2, bitmask=0x71) #F
        display.set_digit_raw(3, bitmask=0x71) #F
        display.write_display()

##       if taster1 == 0:
##            display.clear()
##            display.set_digit_raw(0, bitmask=0x08) #_
##            display.set_digit_raw(1, bitmask=0x3F) #O
##            display.set_digit_raw(2, bitmask=0x54) #n
##            display.set_digit_raw(3, bitmask=0x08) #_
##            display.write_display()
##            taster1 = 1
##        elif taster1 == 1:
##            display.clear()
##            display.set_digit_raw(0, bitmask=0x00) #
##            display.set_digit_raw(1, bitmask=0x3F) #O
##            display.set_digit_raw(2, bitmask=0x71) #F
##            display.set_digit_raw(3, bitmask=0x71) #F
##            display.write_display()
##            taster1 = 0
        volume = 60	#Lautstärke nach dem Einschalten
        vlc.volume(volume)
        taster1 = 0
        taster2 = 0
        taster3 = 0
        taster4 = 0
        taster5 = 0
        while S1 == GPIO.LOW:
            time.sleep(0.1)
        time.sleep(1)
    if GPIO.input(S2) == GPIO.LOW:
        #print("Taster 2")
        display.clear()
        display.set_digit(0, taster2+1)
        display.write_display()
        selPos = 0
        selChannel = taster2+1
        vlc.clear()
        if taster2 == 0:
            vlc.add("http://mp3channels.webradio.antenne.de/antenne")	#Internetstream 1/1
            taster2 = 1
        elif taster2 == 1:
            vlc.add("http://mp3channels.webradio.antenne.de/rockantenne")	#Internetstream 1/2
            taster2 = 2
        elif taster2 == 2:
            vlc.add("http://mp3channels.webradio.antenne.de/80er-kulthits")	#Internetstream 1/3
            taster2 = 0
        
        while S2 == GPIO.LOW:
            time.sleep(0.1)
        time.sleep(1)
    if GPIO.input(S3) == GPIO.LOW:
        #print("Taster 3")
        display.clear()
        display.set_digit(1, taster3+1)
        display.write_display()
        selPos = 1
        selChannel = taster3+1
        vlc.clear()
        if taster3 == 0:
            vlc.add("http://streams.br.de/bayern3_2.m3u")	#Internetstream 2/1
            taster3 = 1
        elif taster3 == 1:
            vlc.add("http://streams.ffh.de/radioffh/mp3/hqlivestream.m3u")	#Internetstream 2/2
            taster3 = 2
        elif taster3 == 2:
            vlc.add("http://metafiles.gl-systemhaus.de/hr/hr1_2.m3u")	#Internetstream 2/3
            taster3 = 0
        
        while S3 == GPIO.LOW:
            time.sleep(0.1)
        time.sleep(1)
    if GPIO.input(S4) == GPIO.LOW:
        #print("Taster 4")
        display.clear()
        display.set_digit(2, taster4+1)
        display.write_display()
        selPos = 2
        selChannel = taster4+1
        vlc.clear()
        if taster4 == 0:
            vlc.add("http://snd.radio-z.net:8000/Radio-Z")	#Internetstream 3/1
            taster4 = 1
        elif taster4 == 1:
            vlc.add("http://sunshinelive.hoerradar.de/sunshinelive-classics-mp3-hq")	#Internetstream 3/2
            taster4 = 2
        elif taster4 == 2:
            vlc.add("http://rpr1.fmstreams.de/stream1.m3u")	#Internetstream 3/3
            taster4 = 0
        
        while S4 == GPIO.LOW:
            time.sleep(0.1)
        time.sleep(1)
    if GPIO.input(S5) == GPIO.LOW:
        #print("Taster 5")
        display.clear()
        display.set_digit(3, taster5+1)
        display.write_display()
        selPos = 3
        selChannel = taster5+1
        vlc.clear()
        if taster5 == 0:
            vlc.add("/home/pi/Music/Playlists/Favourites.m3u")	#Internetstream 4/1	in diesem Fall eine Playlist
            taster5 = 1
        elif taster5 == 1:
            vlc.add("http://stream.hoerradar.de/mp3-radiobob")	#Internetstream 4/2
            taster5 = 2
        elif taster5 == 2:
            vlc.add("http://webstream.gong971.de/gong971")	#Internetstream 4/3
            taster5 = 0
        
        while S5 == GPIO.LOW:
            time.sleep(0.1)
        time.sleep(1)
    if GPIO.input(ENC_ENTER) == GPIO.LOW:
        #print("Drehgeber ENTER")
        display.clear()
        display.set_digit(selPos, selChannel)   #Anzeige, welcher Taster/Kanal gewählt wurde
        display.write_display()

        while S5 == GPIO.LOW:
            time.sleep(0.1)
        time.sleep(1)
    
    now = datetime.datetime.now()
    hour = now.hour
    minute = now.minute
    second = now.second
    if (lastSecond != second) & (noTimeUpdate == 0):
        # Stunden anzeigen
        display.set_digit(0, int(hour / 10))   #Zehnerstunden
        display.set_digit(1, hour % 10)        #Einerstunden
        # Minuten anzeigen
        display.set_digit(2, int(minute / 10)) #Zehnerminuten
        display.set_digit(3, minute % 10)      #Einerminuten
        # Doppelpunkt toggeln lassen
        display.set_colon(second % 2)
        display.write_display()
        # Eine Sekunde warten
        lastSecond = second
    noTimeUpdate -= 1
    if( noTimeUpdate <= 0 ):
        noTimeUpdate = 0
    time.sleep(0.1)

